

.define TESTING mov.w r1, r0    /*   ; put r1 in r0 */
.define BLAH mov.w r3, r2     // put r1 in r0

blah equ 1000   /* ; roar


 */

start:
  TESTING
  TESTING
  TESTING
  TESTING
  TESTING
  truck

  mov.w #blah, 1000

