;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; msp430 include file generated by make_include.py
;; part of the naken430asm msp430 assembler
;;
;; Generated by: (put your name / email here)
;;   Input File: msp430f16x.txt
;;         Date: 2011-06-19 14:26
;;        Parts: (put supported parts here)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; DMA

DMA2SZ equ 0x01f6         ; DMA channel 2 transfer size
DMA2DA equ 0x01f4         ; DMA channel 2 destination address
DMA2SA equ 0x01f2         ; DMA channel 2 source address
DMA2CTL equ 0x01f0        ; DMA channel 2 control
DMA1SZ equ 0x01ee         ; DMA channel 1 transfer size
DMA1DA equ 0x01ec         ; DMA channel 1 destination address
DMA1SA equ 0x01ea         ; DMA channel 1 source address
DMA1CTL equ 0x01e8        ; DMA channel 1 control
DMA0SZ equ 0x01e6         ; DMA channel 0 transfer size
DMA0DA equ 0x01e4         ; DMA channel 0 destination address
DMA0SA equ 0x01e2         ; DMA channel 0 source address
DMA0CTL equ 0x01e0        ; DMA channel 0 control
DMACTL1 equ 0x0124        ; DMA module control 1
DMACTL0 equ 0x0122        ; DMA module control 0

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; DAC12

DAC12_1DAT equ 0x01ca     ; DAC12_1 data
DAC12_1CTL equ 0x01c2     ; DAC12_1 control
DAC12_0DAT equ 0x01c8     ; DAC12_0 data
DAC12_0CTL equ 0x01c0     ; DAC12_0 control

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; ADC12 Interrupt-vector-word register

ADC12IV equ 0x01a8        ; 
ADC12IE equ 0x01a6        ; Inerrupt-enable register
ADC12IFG equ 0x01a4       ; Inerrupt-flag register
ADC12CTL1 equ 0x01a2      ; Control register 1
ADC12CTL0 equ 0x01a0      ; Control register 0
ADC12MEM15 equ 0x015e     ; Conversion memory 15
ADC12MEM14 equ 0x015c     ; Conversion memory 14
ADC12MEM13 equ 0x015a     ; Conversion memory 13
ADC12MEM12 equ 0x0158     ; Conversion memory 12
ADC12MEM11 equ 0x0156     ; Conversion memory 11
ADC12MEM10 equ 0x0154     ; Conversion memory 10
ADC12MEM9 equ 0x0152      ; Conversion memory 9
ADC12MEM8 equ 0x0150      ; Conversion memory 8
ADC12MEM7 equ 0x014e      ; Conversion memory 7
ADC12MEM6 equ 0x014c      ; Conversion memory 6
ADC12MEM5 equ 0x014a      ; Conversion memory 5
ADC12MEM4 equ 0x0148      ; Conversion memory 4
ADC12MEM3 equ 0x0146      ; Conversion memory 3
ADC12MEM2 equ 0x0144      ; Conversion memory 2
ADC12MEM1 equ 0x0142      ; Conversion memory 1
ADC12MEM0 equ 0x0140      ; Conversion memory 0
ADC12MCTL15 equ 0x008f    ; ADC memory-control register15
ADC12MCTL14 equ 0x008e    ; ADC memory-control register14
ADC12MCTL13 equ 0x008d    ; ADC memory-control register13
ADC12MCTL12 equ 0x008c    ; ADC memory-control register12
ADC12MCTL11 equ 0x008b    ; ADC memory-control register11
ADC12MCTL10 equ 0x008a    ; ADC memory-control register10
ADC12MCTL9 equ 0x0089     ; ADC memory-control register9
ADC12MCTL8 equ 0x0088     ; ADC memory-control register8
ADC12MCTL7 equ 0x0087     ; ADC memory-control register7
ADC12MCTL6 equ 0x0086     ; ADC memory-control register6
ADC12MCTL5 equ 0x0085     ; ADC memory-control register5
ADC12MCTL4 equ 0x0084     ; ADC memory-control register4
ADC12MCTL3 equ 0x0083     ; ADC memory-control register3
ADC12MCTL2 equ 0x0082     ; ADC memory-control register2
ADC12MCTL1 equ 0x0081     ; ADC memory-control register1
ADC12MCTL0 equ 0x0080     ; ADC memory-control register0

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Timer_B7/Timer_B3

TBCCR6 equ 0x019e         ; Capture/compare register 6
TBCCR5 equ 0x019c         ; Capture/compare register 5
TBCCR4 equ 0x019a         ; Capture/compare register 4
TBCCR3 equ 0x0198         ; Capture/compare register 3
TBCCR2 equ 0x0196         ; Capture/compare register 2
TBCCR1 equ 0x0194         ; Capture/compare register 1
TBCCR0 equ 0x0192         ; Capture/compare register 0
TBR equ 0x0190            ; Timer_B register
TBCCTL6 equ 0x018e        ; Capture/compare control 6
TBCCTL5 equ 0x018c        ; Capture/compare control 5
TBCCTL4 equ 0x018a        ; Capture/compare control 4
TBCCTL3 equ 0x0188        ; Capture/compare control 3
TBCCTL2 equ 0x0186        ; Capture/compare control 2
TBCCTL1 equ 0x0184        ; Capture/compare control 1
TBCCTL0 equ 0x0182        ; Capture/compare control 0
TBCTL equ 0x0180          ; Timer_B control
TBIV equ 0x011e           ; Timer_B interrupt vector

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Timer_A3

; Reserved 017Eh
; Reserved 017Ch
; Reserved 017Ah
; Reserved 0178h
TACCR2 equ 0x0176         ; Capture/compare register 2
TACCR1 equ 0x0174         ; Capture/compare register 1
TACCR0 equ 0x0172         ; Capture/compare register 0
TAR equ 0x0170            ; Timer_A register
; Reserved 016Eh
; Reserved 016Ch
; Reserved 016Ah
; Reserved 0168h

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Timer_A3

TACCTL2 equ 0x0166        ; Capture/compare control 2
TACCTL1 equ 0x0164        ; Capture/compare control 1
TACCTL0 equ 0x0162        ; Capture/compare control 0
TACTL equ 0x0160          ; Timer_A control
TAIV equ 0x012e           ; Timer_A interrupt vector

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Hardware Multiplier (MSP430F16x and MSP430F161x only)

SUMEXT equ 0x013e         ; Sum extend
RESHI equ 0x013c          ; Result high word
RESLO equ 0x013a          ; Result low word
OP2 equ 0x0138            ; Second operand
MACS equ 0x0136           ; Multiply signed +accumulate/operand1
MAC equ 0x0134            ; Multiply+accumulate/operand1
MPYS equ 0x0132           ; Multiply signed/operand1
MPY equ 0x0130            ; Multiply unsigned/operand1

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Flash

FCTL3 equ 0x012c          ; Flash control 3
FCTL2 equ 0x012a          ; Flash control 2
FCTL1 equ 0x0128          ; Flash control 1

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Watchdog

WDTCTL equ 0x0120         ; Watchdog Timer control

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; USART1 (MSP430F16x and MSP430F161x only)

U1TXBUF equ 0x007f        ; Transmit buffer
U1RXBUF equ 0x007e        ; Receive buffer
U1BR1 equ 0x007d          ; Baud rate
U1BR0 equ 0x007c          ; Baud rate
U1MCTL equ 0x007b         ; Modulation control
U1RCTL equ 0x007a         ; Receive control
U1TCTL equ 0x0079         ; Transmit control
U1CTL equ 0x0078          ; USART control

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; USART0 (UART or SPI mode)

U0TXBUF equ 0x0077        ; Transmit buffer
U0RXBUF equ 0x0076        ; Receive buffer
U0BR1 equ 0x0075          ; Baud rate
U0BR0 equ 0x0074          ; Baud rate
U0MCTL equ 0x0073         ; Modulation control
U0RCTL equ 0x0072         ; Receive control
U0TCTL equ 0x0071         ; Transmit control
U0CTL equ 0x0070          ; USART control

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; USART0 (I2C mode)

I2CIV equ 0x011c          ; I2C interrupt vector
I2CSA equ 0x011a          ; I2C slave address
I2COA equ 0x0118          ; I2C own address
I2CDR equ 0x0076          ; I2C data
I2CSCLL equ 0x0075        ; I2C SCLL
I2CSCLH equ 0x0074        ; I2C SCLH
I2CPSC equ 0x0073         ; I2C PSC
I2CDCTL equ 0x0072        ; I2C data control
I2CTCTL equ 0x0071        ; I2C transfer control
U0CTL equ 0x0070          ; USART control
I2CNDAT equ 0x0052        ; I2C data count
I2CIFG equ 0x0051         ; I2C interrupt flag
I2CIE equ 0x0050          ; I2C interrupt enable

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Comparator_A

CAPD equ 0x005b           ; Comparator_A port disable
CACTL2 equ 0x005a         ; Comparator_A control2
CACTL1 equ 0x0059         ; Comparator_A control1

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Basic Clock

BCSCTL2 equ 0x0058        ; Basic clock system control2
BCSCTL1 equ 0x0057        ; Basic clock system control1
DCOCTL equ 0x0056         ; DCO clock frequency control

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; BrownOUT, SVS

SVSCTL equ 0x0055         ; SVS control register (reset by brownout signal)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Port P6

P6SEL equ 0x0037          ; Port P6 selection
P6DIR equ 0x0036          ; Port P6 direction
P6OUT equ 0x0035          ; Port P6 output
P6IN equ 0x0034           ; Port P6 input

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Port P5

P5SEL equ 0x0033          ; Port P5 selection
P5DIR equ 0x0032          ; Port P5 direction
P5OUT equ 0x0031          ; Port P5 output
P5IN equ 0x0030           ; Port P5 input

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Port P4

P4SEL equ 0x001f          ; Port P4 selection
P4DIR equ 0x001e          ; Port P4 direction
P4OUT equ 0x001d          ; Port P4 output
P4IN equ 0x001c           ; Port P4 input

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Port P3

P3SEL equ 0x001b          ; Port P3 selection
P3DIR equ 0x001a          ; Port P3 direction
P3OUT equ 0x0019          ; Port P3 output
P3IN equ 0x0018           ; Port P3 input

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Port P2

P2SEL equ 0x002e          ; Port P2 selection
P2IE equ 0x002d           ; Port P2 interrupt enable
P2IES equ 0x002c          ; Port P2 interrupt-edge select
P2IFG equ 0x002b          ; Port P2 interrupt flag
P2DIR equ 0x002a          ; Port P2 direction
P2OUT equ 0x0029          ; Port P2 output
P2IN equ 0x0028           ; Port P2 input

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Port P1

P1SEL equ 0x0026          ; Port P1 selection
P1IE equ 0x0025           ; Port P1 interrupt enable
P1IES equ 0x0024          ; Port P1 interrupt-edge select
P1IFG equ 0x0023          ; Port P1 interrupt flag
P1DIR equ 0x0022          ; Port P1 direction
P1OUT equ 0x0021          ; Port P1 output
P1IN equ 0x0020           ; Port P1 input

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Special Functions

ME2 equ 0x0005            ; SFR module enable 2
ME1 equ 0x0004            ; SFR module enable 1
IFG2 equ 0x0003           ; SFR interrupt flag2
IFG1 equ 0x0002           ; SFR interrupt flag1
IE2 equ 0x0001            ; SFR interrupt enable2
IE1 equ 0x0000            ; SFR interrupt enable1

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


